//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009 - 2011
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


CPPGateWayPath = get_absolute_file_path('builder_gateway_cpp.sce');

LibraryName = 'libIPD';

FunctionMatrix = ['CloseVideoFile', 'int_CloseVideoFile'; ...
                  'ConvertColorSpace', 'int_ConvertColorSpace'; ...
                  'CreatePixelIndexList', 'int_CreatePixelIndexList'; ...
                  'DistanceTransform', 'int_DistanceTransform'; ...
                  'GetVideoInfo', 'int_GetVideoInfo'; ...
                  'MaskFilter', 'int_MaskFilter'; ...
                  'MatchTemplate', 'int_MatchTemplate'; ...
                  'MedianFilter', 'int_MedianFilter'; ...
                  'MorphologicalFilter', 'int_MorphologicalFilter'; ...
                  'OpenVideoFile', 'int_OpenVideoFile'; ...
                  'ReadImageFile', 'int_ReadImageFile'; ...
                  'ReadImageFromVideo', 'int_ReadImageFromVideo'; ...
                  'SearchBlobs', 'int_SearchBlobs'; ...
                  'SeparableFilter', 'int_SeparableFilter'; ...
                  'VarianceFilter', 'int_VarianceFilter'; ...
                  'Watershed', 'int_Watershed'; ...
                  'WriteImageFile', 'int_WriteImageFile'];
                  
FileList = ['CloseVideoFile.cpp'; ...
            'ConvertColorSpace.cpp'; ...
            'CreatePixelIndexList.cpp'; ...
            'DistanceTransform.cpp'; ...
            'GetVideoInfo.cpp'; ...
            'MaskFilter.cpp'; ...
            'MatchTemplate.cpp'; ...
            'MedianFilter.cpp'; ...
            'MorphologicalFilter.cpp'; ...
            'OpenVideoFile.cpp'; ...
            'ReadImageFile.cpp'; ...
            'ReadImageFromVideo.cpp'; ...
            'SearchBlobs.cpp'; ...
            'SeparableFilter.cpp'; ...
            'VarianceFilter'; ...
            'Watershed.cpp'; ...
            'WriteImageFile.cpp']; 
                        
IncludePath = '-I""' + CPPGateWayPath + 'include""';

OperatingSystem = convstr(getos(), 'l');

if OperatingSystem == 'windows' then

 ListOfLibraries = ['cxcore210', 'cv210', 'highgui210'];

else

 ListOfLibraries = ['libcxcore', 'libcv', 'libhighgui'];

end;

Architecture = Options(2); // defined by [VersionName, Options] = getversion();

LibraryPath = '-LIBPATH:""' ...
            + ToolboxPath ...
            + 'Thirdparty' ...
            + filesep() ...
            + 'opencv' ...
            + filesep() ...
            + OperatingSystem ...
            + filesep() ...
            + Architecture ...
            + '""';

tbx_build_gateway(LibraryName, ...
                  FunctionMatrix, ...
                  FileList, ...
                  CPPGateWayPath, ...
                  ListOfLibraries, ...
                  LibraryPath, ...
                  IncludePath);

for n = 1 : size(ListOfLibraries, 2)

 LibraryName = ListOfLibraries(n) + getdynlibext();
 
 SourcePath = ToolboxPath ...
            + 'Thirdparty' ...
            + filesep() ...
            + 'opencv' ...
            + filesep() ...
            + OperatingSystem ...
            + filesep() ...
            + Architecture ...
            + filesep();
 
 DestinationPath = CPPGateWayPath + LibraryName;
 
 SourcePath = SourcePath + LibraryName;
 
 copyfile(SourcePath, DestinationPath);

end;

clear LibraryName;

clear LibraryPath;

clear CPPGateWayPath;
                  
clear FunctionMatrix;

clear FileList;

clear ListOfLibraries; 

clear IncludePath;

clear OperatingSystem;

clear Architecture;

clear SourcePath;

clear DestinationPath;
             